/* NOTES:
	This .do file goes through the data cleaning and analysis as used in the paper in the Journal of Social Policy
	HOWEVER, local area data (for the analyses on dependency culture) are not included as they are potentially highly disclosive
	If you are interested in re-running some of the analyses using local area data, please get in touch with me (b.b.geiger@kent.ac.uk)
	and I'll be happy to discuss this with you.
*/

version 12
capture noisily which estout
	if _rc~=0 	ssc install estout, replace			// Requires the latest version of this to run
macro drop _all						// Must do this BEFORE setting the dir globals below!
	pause on
	set more off
// Directory
global dodir 		"C:\Users\bpb\Dropbox\WS\Stigma proposal 2012\1. MORI survey"
global sharingdir 	"${dodir}\0. Dataset to share"
// Follow-on dirs
capture log close
	local cmth = month(date("`c(current_date)'", "DMY"))
	local cyr  = year(date("`c(current_date)'", "DMY"))
	log using "$dodir\logs\MORI`cyr'-`cmth'.txt", text append
global filename "MORI-v1-06"									// Merged media vars

exit



//////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////
// THE DATA 
//////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////

* This is the syntax for taking the authors dataset, and creating the sharing dataset
use "${dodir}\\${filename}.dta", replace
* Removing disclosive variables
drop TCrateR-nonwest AllrateR papercount declancount paper1-pap_frdM pattern*
* Tidying up
recode week (218=1)(220=2)(221=3)
gen 	 claimsESA	= (benESA==1 | benISoth==1) if ~missing(benESA) & ~missing(benISoth)
drop wts
order noTCistigma-noTCnonstig, after(noTCnone)
order noBENistigma-noBENnonstig, after(noBENnone)
order benSPar claimsESA ben_outofwrk ben_other anyben estfraud surveyexp, after(benNone)
order benDIS disvisible disvisible3, after(INSstigma)
order daily* sunday* papread paptype, last
drop bencount? screen? estfraud10 INSstigmaR INSstigcat equivscale incnum equivinc agegrpR inwork inworkcie qual4 nonwhite papread paptype		// dvs not needed for sharing
* Labelling
label var serial "Serial number (unique identifier)"
label var week "Week of data collection (see questionnaires)"
label var wtnew "Survey weight (BBG recalculated weight)"
label var numage "Age in years"
label var agegrp "Age group"
label var male "Gender is male (vs female)"
label var benJSA "WS01 Own claims: Unemployment benefits "
label var benESA "WS01 Own claims: Incapacity benefits "
label var benIS "WS01 Own claims: Income support"
label var benISoth "WS01 Own claims: Wage top-ups"
label var benHB "WS01 Own claims: Housing benefit"
label var benCTB "WS01 Own claims: Council tax benefit"
label var benTCwork "WS01 Own claims: Wage top-ups"
label var benTCnowrk "WS01 Own claims: Out of work tax credits"
label var benDLA "WS01 Own claims: DLA"
label var benCA "WS01 Own claims: Carer's allowance"
label var benPC "WS01 Own claims: Pension Credit"
label var benCB "WS01 Own claims: Child Benefit"
label var benBSP "WS01 Own claims: Basic State Pension"
label var benOther "WS01 Own claims: Other"
label var benNone "WS01 Own claims: None"
label var benSPar "Own claims: derived variable for Single Parent IS"
label var claimsESA "Own claims: derived variable for out-of-work disability benefits"
label var ben_outofwrk "Own claims: out-of-work benefit (benJSA benESA benIS benTCnowrk)"
label var ben_other "Own claims: other benefit (benHB benCTB benDLA benCA)"
label var anyben "ben_outofwrk ben_other == 1"
label var estfraud "WS02/WS09: Perceived out-of-work benefit fraud, out of every 100 claimants"
label var surveyexp "WS02 vs. WS09: Whether start or end with estfraud question"
label var IstigmaTC "WS03 Personal stigma: in-work Tax Credits"
label var IstigmaJSA "WS03 Personal stigma: Jobseekers Allowance"
label var IstigmaESA "WS03 Personal stigma: Employment & Support Allowance"
label var IstigmaISSP "WS03 Personal stigma: Income Support for single parents"
label var IstigmaHB "WS03 Personal stigma: Housing Benefit"
label var Istigma "Personal stigma: summary score (0-100)"
label var EstigmaTC "WS04 Stigmatisation: in-work Tax Credits"
label var EstigmaJSA "WS04 Stigmatisation: Jobseekers Allowance"
label var EstigmaESA "WS04 Stigmatisation: Employment & Support Allowance"
label var EstigmaISSP "WS04 Stigmatisation: Income Support for single parents"
label var EstigmaHB "WS04 Stigmatisation: Housing Benefit"
label var Estigma "Stigmatisation: summary score (0-100)"
label var INSstigma "WS05 Institutional stigma"
label var benDIS "Screening question for WS06 that follows"
label var disvisible "WS06 Visibility of disability"
label var disvisible3 "WS06 Visibility of disability grouped"
label var TCclaimant "Filter for A vs. B in following section: whether claims any in-work Tax Credits"
label var noTCinfo "WS07: Wont claim TCs: personal information"
label var noTCestigma "WS07: Wont claim TCs: how others would react"
label var noTCfeel "WS07: Wont claim TCs: how would feel yourself"
label var noTCentitl "WS07: Wont claim TCs: unsure if entitled"
label var noTChassle "WS07: Wont claim TCs: too much hassle"
label var noTCidentity "WS07: Wont claim TCs: for other people not me"
label var noTCins "WS07: Wont claim TCs: how would be treated"
label var noTCna "WS07: Wont claim TCs: other (not applicable to me)"
label var noTCgetjob "WS07: Wont claim TCs: other (would be able to get job)personal information"
label var noTCoth "WS07: Wont claim TCs: other (another reason)"
label var noTCnone "WS07: Wont claim TCs: none"
label var noTCistigma "Wont claim TCs: personal stigma-related (noTCfeel noTCidentity)"
label var noTCinsstig "Wont claim TCs: institutional stigma-related (noTCins noTCinfo)"
label var noTCanystig "Wont claim TCs: any stigma-related (noTCistigma noTCestigma noTCinsstig)"
label var noTCnonstig "Wont claim TCs: non-stigma-relted (noTChassle noTCentitl)"
label var benclaimant "Filter for A vs. B in following section: whether claims any out-of-work benefits"
label var noBENinfo "WS08: Wont claim benefits: personal information"
label var noBENestigma "WS08: Wont claim benefits: how others would react"
label var noBENfeel "WS08: Wont claim benefits: how would feel yourself"
label var noBENentitl "WS08: Wont claim benefits: unsure if entitled"
label var noBENhassle "WS08: Wont claim benefits: too much hassle"
label var noBENident~y "WS08: Wont claim benefits: for other people not me"
label var noBENins "WS08: Wont claim benefits: how would be treated"
label var noBENna "WS08: Wont claim benefits: other (not applicable to me)"
label var noBENgetjob "WS08: Wont claim benefits: other (would be able to get job)personal information"
label var noBENoth "WS08: Wont claim benefits: other (another reason)"
label var noBENnone "WS08: Wont claim benefits: none"
label var noBENistigma "Wont claim benefits: personal stigma-related (noBENfeel noBENidentity)"
label var noBENinsstig "Wont claim benefits: institutional stigma-related (noBENins noBENinfo)"
label var noBENanystig "Wont claim benefits: any stigma-related (noBENistigma noBENestigma noBENinsstig)"
label var noBENnonstig "Wont claim benefits: non-stigma-relted (noBENhassle noBENentitl)"
label var region "Sociodemographics: region of residence"
label var work "Sociodemographics: work status"
label var cie "Sociodemographics: whether chief income earner"
label var wrkcie "Sociodemographics: working status of CIE"
label var sgrade "Sociodemographics: social grade"
label var income "Sociodemographics: income (banded)"
label var income3 "Sociodemographics: income (grouped version of the variable income)"
label var ethnic "Sociodemographics: ethnic origin"
label var qual "Sociodemographics: education"
label var numadults "Sociodemographics: number of adults"
label var marstat "Sociodemographics: marital status (RECODE of maritl)"
label var kidshhld "Sociodemographics: number of children (RECODE of numkid2)"
label var tenure3 "Sociodemographics: housing tenure (RECODE of tenure)"
label var daily1 "Daily newspaper: 1.     The Herald (Scotland)"
label var daily2 "Daily newspaper: 2.     The Independent"
label var daily3 "Daily newspaper: 3.     The Daily Telegraph"
label var daily4 "Daily newspaper: 4.     The Guardian"
label var daily5 "Daily newspaper: 5.     Financial Times"
label var daily6 "Daily newspaper: 6.     The Times"
label var daily7 "Daily newspaper: 7.     The Scotsman"
label var daily8 "Daily newspaper: 8.     Daily Express"
label var daily9 "Daily newspaper: 9.     Daily Mail"
label var daily10 "Daily newspaper: 10.  Metro"
label var daily11 "Daily newspaper: 11.  Daily Record"
label var daily12 "Daily newspaper: 12.  The Sun"
label var daily13 "Daily newspaper: 13.  Daily Mirror"
label var daily14 "Daily newspaper: 14.  Daily Star"
label var daily15 "Daily newspaper: 15.  Evening Standard"
label var daily16 "Daily newspaper: 16.  Western Mail (Wales)"
label var daily17 "Daily newspaper: 17.  Belfast Telegraph"
label var daily18 "Daily newspaper: 18.  Irish News"
label var daily19 "Daily newspaper: 19.  News Letter (Ulster)"
label var daily20 "Daily newspaper: 20.  i newspaper"
label var daily21 "Daily newspaper: 21.  Don't Know"
label var daily22 "Daily newspaper: 22.  No answer"
label var daily23 "Daily newspaper: 23. Tabloid"
label var daily24 "Daily newspaper: 24.  None of these"
label var daily25 "Daily newspaper: 25. Don’t know"
label var sunday1 "Sunday newspaper: 1.     Sunday Mail (Scotland)"
label var sunday2 "Sunday newspaper: 2.     The Mail on Sunday"
label var sunday3 "Sunday newspaper: 3.     The Sunday Post"
label var sunday4 "Sunday newspaper: 4.     The Independent on Sunday"
label var sunday5 "Sunday newspaper: 5.     The Sunday Times"
label var sunday6 "Sunday newspaper: 6.     The Sunday Telegraph"
label var sunday7 "Sunday newspaper: 7.     Sunday Express"
label var sunday8 "Sunday newspaper: 8.     The Observer"
label var sunday9 "Sunday newspaper: 9.     News of the World"
label var sunday10 "Sunday newspaper: 10.  The People"
label var sunday11 "Sunday newspaper: 11.  Sunday Mirror"
label var sunday12 "Sunday newspaper: 12.  Sunday Sport"
label var sunday13 "Sunday newspaper: 13.  Scotland on Sunday"
label var sunday14 "Sunday newspaper: 14.  Daily Star Sunday"
label var sunday15 "Sunday newspaper: 15.  The Sun (Sunday)"
label var sunday16 "Sunday newspaper: 16.  Don't Know"
label var sunday17 "Sunday newspaper: 17.  No answer"
save "${sharingdir}\JSP2016_dataset_basedonV1-06.dta", replace
savespss "${sharingdir}\JSP2016_dataset_basedonV1-06.sav", replace
	
	
//////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////
// RESULTS FOR 2014 paper
//////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////

// To start
estimates clear
set matsize 10000
do "${dodir}\6_paper_2014_furthercleaning.do"	// This loads "${dodir}\\${filename}_paper2014" automatically

	

// Main estimates
do "$dodir\6_paper_2014_results_desc.do"
do "$dodir\6_paper_2014_results_reg.do"		
