////////////////////////////////////////////////////
////////////////////////////////////////////////////
// FURTHER DATA CLEANING
////////////////////////////////////////////////////
////////////////////////////////////////////////////

use "${dodir}\\${filename}", replace


////////////////////////////////////////////////////
// Renaming benefit claim variables to enable easier looping
// 14/8/2014 
clonevar claimsTC 	= benTCwork 
clonevar claimsJSA	= benJSA	
gen 	 claimsESA	= (benESA==1 | benISoth==1) if ~missing(benESA) & ~missing(benISoth)
clonevar claimsISSP	= benSPar
clonevar claimsHB	= benHB

* And something to do PROPORTION, OVER(x) on
label define claims3 1 "1_claims this ben" 2 "2_claims another ben" 3 "3_not ben claimant"
foreach ben in TC JSA ESA ISSP HB	{
	gen 	claimsplit`ben' = 1 if claims`ben'==1
	replace claimsplit`ben' = 0 if claims`ben'==0 & anyben==1
	*replace claimsplit`ben' = 2 if claims`ben'==0 & anyben==0
	label var claimsplit`ben' "Claimants of this ben vs. claimants in general"
/**/								}

* Creating a single categorical var with ben claims in, excluding HB
foreach ben in TC JSA ESA ISSP HB	{
	mean claimsTC-claimsHB if claims`ben'==1 [pweight=wtnew]
/**/								}
egen claimpattern = concat(claimsTC-claimsISSP)
label define claimgroup 0 "0_no claim" 1 "1_mixed claim" 2 "2_only TCs" 3 "3_only JSA" 4 "4_onlyESA" 5 "5_only ISSP"
gen claimgroup 		= 0 if claimpattern=="0000"
replace claimgroup 	= 1 if claimpattern~="0000" & ~missing(claimsESA)
replace claimgroup 	= 2 if claimpattern=="1000"
replace claimgroup 	= 3 if claimpattern=="0100"
replace claimgroup 	= 4 if claimpattern=="0010"
replace claimgroup 	= 5 if claimpattern=="0001"
label var claimgroup "Claiming group, excluding HB"
label values claimgroup claimgroup



////////////////////////////////////////////////////
// OUTCOME VARIABLES
// 14/8/2014 adapted from 20/11/2012 

capture drop ?stigma*c
foreach ben in TC JSA ESA ISSP HB 	{
		foreach Z in E I 				{
			recode `Z'stigma`ben' (0/4=1 "1_disagree") (5=2 "2_neither") (6/10=3 "3_agree"), gen(`Z'stigma`ben'c) 
		/**/						}
/**/							}
recode INSstigmaR (0/4=1 "1_agree") (5=2 "2_neither") (6/10=3 "3_disagree"), gen(INSstigmaRc) 

// Pattern of stigma, exc. summary across all benefits
foreach Z in E I 				{
	egen `Z'stigma_pattern 	= concat(`Z'stigma*c)
	egen `Z'stigma_miss 	= rowmiss(`Z'stigma*c)
	replace `Z'stigma_pattern = "." if `Z'stigma_miss>0
	drop `Z'stigma_miss
/**/							}

// A summary across all benefits
foreach Z in E I	{
	egen `Z'stigmaALL = rowmax(`Z'stigmaTC-`Z'stigmaHB)
		label var `Z'stigmaALL 	"Maximum `Z'stigma across five benefits"
	egen `Z'stigmaALLc = rowmax(`Z'stigma*c)
		label var `Z'stigmaALLc "Maximum `Z'stigmac across five benefits"
		label values `Z'stigmaALLc IstigmaTCc
/**/				}

// Internal vs. external feelings for individual benefits
capture drop Eminus*
label define EminusIc 1 "1_Neither stigma" 2 "2_stigmatised not felt" 3 "3_felt not stigmatised" 4 "4_both stigmas", modify
foreach ben in ALL TC JSA ESA ISSP HB 	{
		gen EminusI_`ben'  = Estigma`ben'  - Istigma`ben'
			recode EminusI_`ben' (min/-1=1 "1_I>E")(0=2 "2_E=I")(1/max=3 "3_E>I")(else=.), gen(EminusI_`ben'g)
			drop EminusI_`ben'
		gen EminusI_`ben'c 		= 1 if Estigma`ben'c<=2 & Istigma`ben'c<=2
			replace EminusI_`ben'c 	= 2 if Estigma`ben'c==3 & Istigma`ben'c<=2
			replace EminusI_`ben'c 	= 3 if Estigma`ben'c<=2 & Istigma`ben'c==3
			replace EminusI_`ben'c 	= 4 if Estigma`ben'c==3 & Istigma`ben'c==3		
			label values EminusI_`ben'c  EminusIc 
/**/							}

// People's own benefits stigma (max if claiming multiple vars)
capture drop *selfc
foreach Z in E I 				{
	gen `Z'stigma_selfc = .
	label values `Z'stigma_selfc IstigmaTCc
	foreach ben in TC JSA ESA ISSP HB 	{
		replace `Z'stigma_selfc = `Z'stigma`ben'c if claims`ben'==1 & missing(`Z'stigma_selfc)
		replace `Z'stigma_selfc = `Z'stigma`ben'c if claims`ben'==1 & `Z'stigma`ben'c>`Z'stigma_selfc & ~missing(`Z'stigma`ben'c)
	/**/							}	
/**/							}


// New combined stigma variable
gen allstigma 		= (IstigmaALLc==3 | EstigmaALLc==3 | noBENanystig==1) if ~missing(IstigmaALLc, EstigmaALLc, noBENanystig)
replace allstigma 	= 2 if INSstigmaRc==3 & allstigma==0
	label define allstigma 0 "0_no stigma" 1 "1_stigma" 2 "2_ONLY claims stigma", modify
	label values allstigma allstigma
recode allstigma (0 2=0 "0_no stigma or claims stigma only")(1=1 "1_stigma reported"), gen(allstigmaB)


////////////////////////////////////////////////////
// FINAL TIDYING FOR REGRESSIONS
// 15/8/2014

* MLOGIT fails without editing some of the value labels (copied from BSA)
unab outcomes:	allstigmaB IstigmaALLc EstigmaALLc INSstigmaRc no*istigma no*estigma no*insstig no*anystig no*nonstig no*none
foreach var in `outcomes'	{
	global N`var' ""
	levelsof `var'
	foreach i in `r(levels)'	{
		local labelchange: label (`var') `i'
		if length(`"`labelchange'"')>1	{
			local labelchange = substr(subinstr(`"`labelchange'"', ",", "", .),1,30)		// I just raised this from length=25, hopefully MLOGIT can cope
			dis `i' `" `labelchange'"'
			label define N`var' `i' `"`labelchange'"', modify
			/**/							}
		/**/					}
	label values `var' N`var'
/**/					}


////////////////////////////////////////////////////
// OUTPUTS FROM DATA CLEANING
// 14/8/2014

log using "$dodir\0_desc_outputs.txt", text replace name(desc_outputs)
	// Output for pattern across different benefits (then dropped as don't want to do PROPORTION on it!)
	dis in blue _newline(10) "This is an output for a var that is then dropped"
	tab1 ?stigma_pattern
	drop ?stigma_pattern
	// Further simple outputs
	prop benclaimant TCclaimant [pweight=wtnew]
	prop allstigma [pweight=wtnew]	
	// Among claimants
	prop allstigma if benclaimant==1 [pweight=wtnew]
	prop EminusI_ALLc if benclaimant==1 [pweight=wtnew]
	// Further crosstabs
	prop IstigmaALLc EstigmaALLc [pweight=wtnew]	
		lincom _b[EstigmaALLc:_prop_6] - _b[IstigmaALLc:_prop_3]
	prop IstigmaTCc IstigmaJSAc IstigmaESAc IstigmaISSPc IstigmaHBc [pweight=wtnew]
		* TC comparisons
		lincom _b[IstigmaTCc:_prop_3] - _b[IstigmaHBc:_prop_15] 
		lincom _b[IstigmaTCc:_prop_3] - _b[IstigmaISSPc:_prop_12] 
		lincom _b[IstigmaTCc:_prop_3] - _b[IstigmaESAc:_prop_9] 
		lincom _b[IstigmaTCc:_prop_3] - _b[IstigmaJSAc:_prop_6] 
		* ESA comparisons
		lincom _b[IstigmaESAc:_prop_9] - _b[IstigmaJSAc:_prop_6] 
		lincom _b[IstigmaESAc:_prop_9] - _b[IstigmaISSPc:_prop_12] 
		lincom _b[IstigmaESAc:_prop_9] - _b[IstigmaHBc:_prop_15] 
		* Overall
		test (_b[IstigmaHBc:_prop_15] = _b[IstigmaISSPc:_prop_12] = _b[IstigmaESAc:_prop_9] = _b[IstigmaJSAc:_prop_6] = _b[IstigmaTCc:_prop_3] )
	prop EstigmaTCc EstigmaJSAc EstigmaESAc EstigmaISSPc EstigmaHBc [pweight=wtnew]
		* TC comparisons
		lincom _b[EstigmaTCc:_prop_3] - _b[EstigmaHBc:_prop_15] 
		lincom _b[EstigmaTCc:_prop_3] - _b[EstigmaISSPc:_prop_12] 
		lincom _b[EstigmaTCc:_prop_3] - _b[EstigmaESAc:_prop_9] 
		lincom _b[EstigmaTCc:_prop_3] - _b[EstigmaJSAc:_prop_6] 
		* ESA comparisons
		lincom _b[EstigmaESAc:_prop_9] - _b[EstigmaJSAc:_prop_6] 
		lincom _b[EstigmaESAc:_prop_9] - _b[EstigmaISSPc:_prop_12] 
		lincom _b[EstigmaESAc:_prop_9] - _b[EstigmaHBc:_prop_15] 
		* Overall
		test (_b[EstigmaHBc:_prop_15] = _b[EstigmaISSPc:_prop_12] = _b[EstigmaESAc:_prop_9] = _b[EstigmaJSAc:_prop_6] = _b[EstigmaTCc:_prop_3] )
log close desc_outputs
	
* CLEANING
drop daily* sunday* pap* *stigcat*
compress
save "${dodir}\\${filename}_paper2014", replace
