
////////////////////////////////////////////////////
////////////////////////////////////////////////////
// REGRESSIONS ON DEPENDENCY CULTURE
////////////////////////////////////////////////////
////////////////////////////////////////////////////

use "${dodir}\\${filename}_paper2014", replace
estimates clear
clear results
clear matrix		
drop EminusI*


// Setting base values for factor variables to be the MOST advantaged
fvset base 1 inwork tenure
fvset base 4 qual4
// And other sensible base groups
fvset base 1 marstat
fvset base 3 agegrpR
fvset base 8 region

// Runnnig the models
time
global covars1	"i.agegrpR male i.region i.marstat kidshhld ben_outofwrk ben_other benTCwork c.nonwest"	// To report MARGINS for
global covars2	""																						// No MARGINS reported
global sesvars	"c.AllrateR c.unemplMB i.inwork i.tenure3 i.qual4"
global extravars "c.TCrateR c.imdnewR"
unab outcomes:	allstigmaB IstigmaALLc EstigmaALLc INSstigmaRc no*istigma no*estigma no*insstig no*anystig no*nonstig no*none
foreach var in `outcomes'	{
	if "`var'"=="IstigmaALLc" | "`var'"=="EstigmaALLc" | "`var'"=="INSstigmaRc"		local outcat = 3
	else																			local outcat = 1
	// Just the demographics, not the SES patterning - NO LONGER USED IN THE PAPER
	eststo reg1_`var'R:			mlogit `var' ${covars1} ${covars2} 								[pweight=wtnew], vce(cluster DummyLSOA)
	eststo reg1_`var'M:			margins, dydx(ben_outofwrk) 	   predict(outcome(`outcat')) post

	// Looking at each SES var individually
	foreach sesvar in ${sesvars} {
		local strpos 	= strpos("`sesvar' ", ".") + 1
		local trim 		= substr("`sesvar'", `strpos', .)
		eststo reg2_`var'_`trim'R:	mlogit `var' ${covars1} ${covars2} `sesvar' 				[pweight=wtnew], vce(cluster DummyLSOA)
		eststo reg2_`var'_`trim'M:	margins, dydx(`trim') predict(outcome(`outcat')) post
		if strmatch("`sesvar'", "*c.*")==1		{
			estimates restore reg2_`var'_`trim'R
			margins, at((p25) `trim') at((p75) `trim') predict(outcome(`outcat')) post
				lincom _b[2._at] -  _b[1._at]
				estadd scalar cdiff = r(estimate)	: reg2_`var'_`trim'M
		/**/ }						
	/**/ }

	// Mutually adjusted model
	eststo reg3_`var'_sesvarsR:		mlogit `var' ${covars1} ${covars2} ${sesvars} 		[pweight=wtnew], vce(cluster DummyLSOA)
	* MARGINAL EFFECTS FOR THE MUTUALLY ADJUSTED MODEL
		*Categorical variables, starting by getting the right text to run MARGINS (no factor notation)
	local trim = subinstr("${sesvars} ${covars1} ben_outofwrk ben_other benTCwork", "i.", "", .)
	local trim = subinstr("`trim'", "c.", "", .)
	eststo reg3_`var'_sesvarsM:		margins, dydx(`trim') predict(outcome(`outcat')) post
		*Margins for continuous variables, which were excluded from the previous line
	estimates restore reg3_`var'_sesvarsR
	margins, at((p25) AllrateR) at((p75) AllrateR) at((p25) unemplMB) at((p75) unemplMB) predict(outcome(`outcat')) post
		lincom _b[2._at] -  _b[1._at]
		estadd scalar cdiff = r(estimate)		: reg3_`var'_sesvarsM
		lincom _b[4._at] -  _b[3._at]
		estadd scalar cdiff2 = r(estimate)		: reg3_`var'_sesvarsM

	// A final model that adds in further SES controls that I didn't want in the full model, but worth checking
	eststo reg4_`var'_sesvarsR:		mlogit `var' ${covars1} ${covars2} ${sesvars} ${extravars}	[pweight=wtnew], vce(cluster DummyLSOA)
	local trim = subinstr("${sesvars} ${covars1} ${extravars}", "i.", "", .)
	local trim = subinstr("`trim'", "c.", "", .)
	eststo reg4_`var'_sesvarsM:		margins, dydx(`trim') predict(outcome(`outcat')) post
		*Margins for continuous variables, which were excluded from the previous line
	estimates restore reg4_`var'_sesvarsR
	margins, 	at((p25) AllrateR) at((p75) AllrateR) ///
				at((p25) unemplMB) at((p75) unemplMB) ///
				at((p25) TCrateR ) at((p75) TCrateR)  ///
				at((p25) imdnewR)  at((p75) imdnewR)  ///				
				predict(outcome(`outcat')) post
		lincom _b[2._at] -  _b[1._at]
		estadd scalar cdiff = r(estimate)		: reg4_`var'_sesvarsM
		lincom _b[4._at] -  _b[3._at]
		estadd scalar cdiff2 = r(estimate)		: reg4_`var'_sesvarsM
		lincom _b[6._at] -  _b[5._at]
		estadd scalar cdiff3 = r(estimate)		: reg4_`var'_sesvarsM
		lincom _b[8._at] -  _b[7._at]
		estadd scalar cdiff4 = r(estimate)		: reg4_`var'_sesvarsM
/**/ }

// Outputting
set matsize 10000
global outspec "varwidth(25) nonum nodepvars csv coeflabels() replace b(%4.3f)"
esttab reg?_*R using "${dodir}\9_output2R.csv", ${outspec} drop(*o.* *b.* 2_neither:*) not wide star(* 0.10 ** 0.05 *** 0.01) 
esttab reg?_*M using "${dodir}\9_output2M.csv", ${outspec} scalars(cdiff cdiff2 cdiff3 cdiff4 predict_label) sfmt(%5.4f) nostar p(%4.3f) nopar wide 
estwrite * using "${dodir}\9_ests2", replace id(serial)
time
/*
	use "${dodir}\\${filename}_paper2014", replace
	estread "${dodir}\9_ests2", id(serial)
*/

